@@ -1,13 +1,18 @@
 import socket
 from urllib.parse import unquote
+from typing import Literal
 
 
 def format_header(header: str) -> str:
+    """
+    format the given header. Example:format_header('connection:keep-alive') -> 'Connection:Keep-Alive'
+    """
     return '-'.join(map(lambda x: x.capitalize(), header.split('-')))
 
 
 def recv_request_line(conn: socket.socket) -> bytes:
-    stack = b''
+    """Receive the request line (like GET / HTTP/1.1)"""
+    stack = conn.recv(16)
     while b'\r\n' not in stack:
         current_recv = conn.recv(1)
         stack += current_recv
@@ -17,10 +22,8 @@ def recv_request_line(conn: socket.socket) -> bytes:
 
 
 def recv_request_head(conn: socket.socket) -> bytes:
-    timeout = conn.gettimeout()
-    conn.settimeout(0.25)
-    stack = conn.recv(1)
-    conn.settimeout(timeout)
+    """Receive HTTP header (like Host: localhost)"""
+    stack = conn.recv(4)
     while b'\r\n\r\n' not in stack:
         current_recv = conn.recv(1)
         stack += current_recv
@@ -30,6 +33,7 @@ def recv_request_head(conn: socket.socket) -> bytes:
 
 
 def recv_all(conn: socket.socket, buffer: int = 1024) -> bytes:
+    """Receive all data"""
     content = b''
     c = True
     while c:
@@ -39,11 +43,13 @@ def recv_all(conn: socket.socket, buffer: int = 1024) -> bytes:
 
 
 def parse_req(content: bytes) -> dict:
+    """Parse a request data into a dict object in order to construct a Request object"""
     line, *head = content.decode().split('\r\n')
     method, uv = line.split(' ', 1)
     url, ver = uv.rsplit(' ', 1)
-    path, param = unquote(url).split('?', 1) if '?' in url else [url, '']
-    path = path + '/' if not path.endswith('/') else path
+
+    url = unquote(url)
+    path, param = url.split('?', 1) if '?' in url else (url, '')
 
     keyword, arg = {}, set()
     for p in param.split('&'):
@@ -54,17 +60,13 @@ def parse_req(content: bytes) -> dict:
             arg.add(p)
 
     header = {}
-    for h, v in (h.replace(' ', '').split(':', 1) for h in head):
-        header[format_header(h)] = v
+    for h, v in (h.split(':', 1) for h in head):
+        header[format_header(h.strip())] = v.strip()
 
     return {'method': method, 'url': path, 'keyword': keyword,
             'arg': arg, 'version': ver, 'header': header, 'query': '?' + param if param else ''}
 
 
-def shrink_string(s: str, max_len: int = 40):
-    return s[:max_len - 3] + '...' if len(s) > max_len else s
-
-
 HTTP_CODE = {
     100: "Continue",
     101: "Switching Protocols",
@@ -124,5 +126,5 @@ HTTP_CODE = {
     510: "Not Extended",
     600: "Unparseable Response Headers"
 }
-
-__all__ = ['recv_request_line', 'recv_request_head', 'recv_all', 'parse_req', 'HTTP_CODE', 'shrink_string']
+Method = Literal['GET', 'POST', 'PUT', 'DELETE', 'HEAD', 'CONNECT', 'TRACE', 'OPTIONS']
+__all__ = ['recv_request_line', 'recv_request_head', 'recv_all', 'parse_req', 'HTTP_CODE', 'Method']
